@@ -1,5 +1,5 @@
 class.Rud <-
-function( cutscore, ip, ability = NULL, se=NULL, rdm = NULL, quadrature=NULL, D = 1.7){
+function( cutscore, ip, ability = NULL, se = NULL, rdm = NULL, quadrature=NULL, D = 1.7){
 	 	
 		if(is.null(quadrature)==TRUE){
 		if(is.null(ability)==TRUE){
@@ -18,7 +18,7 @@ function( cutscore, ip, ability = NULL, se=NULL, rdm = NULL, quadrature=NULL, D
 			if(length(quadrature)!=2) stop("quadrature points and weights must be a list of legth 2")
 			if(length(quadrature[[1]])!=length(quadrature[[2]])) stop("number of quadrature points and weights do not match")
 			
-		se<-SEM(ip,quadrature[[1]])							
+		se<-SEM(ip,quadrature[[1]], D)							
 		results <- Rud.D(cutscore, quadrature, se)				
 	results}}
 
